@@ -38,9 +38,9 @@ def main(global_config, **settings):
     # Delay imports, so that DynamicSchemaName.use_app_schemas can be updated correctly before AppDataSet etc. tables are imported.
     from tropofy.app import App, AppDataSet, AppManager, LoadedApps
     from tropofy.widgets import Widget
-    App.global_sqla_engine = create_engine(global_sqla_engine)
+    App.global_sqla_engine = create_engine(global_sqla_engine) if global_sqla_engine else None
 
-    authn_policy = AuthTktAuthenticationPolicy('sosecret5872', callback=groupfinder, hashalg='sha512')
+    authn_policy = AuthTktAuthenticationPolicy('lDklAS*)(dA0pDJpasJDIJPkadgsosecret5872', callback=groupfinder, hashalg='sha512')
     authz_policy = ACLAuthorizationPolicy()
     my_session_factory = UnencryptedCookieSessionFactoryConfig('itsatropofyseekreet')
     config = Configurator(
@@ -89,11 +89,18 @@ def main(global_config, **settings):
             return Widget.widget_dict.get(int(request.matchdict['widget_id']), None)
         return None
 
+
+    def get_user_email(request):
+        return authenticated_userid(request)
+
+
     config.add_request_method(get_data_set, 'data_set', reify=True)
     config.add_request_method(get_app, 'app', reify=True)
     config.add_request_method(get_app_if_only_one_app, 'only_app', reify=True)
     config.add_request_method(get_widget, 'widget', reify=True)
     config.add_request_method(get_data_set_id, 'data_set_id', reify=True)
+    config.add_request_method(get_user_email, 'user_email', reify=True)
+
 
     config.add_static_view(name='static', path='static')  # Needed for respond.proxy.gif.
     config.add_renderer('json', json_renderer)  # Custom json renderer.
@@ -132,12 +139,13 @@ def addroutes(config):
     config.add_route('create_new_data_set', '/{app_url_name}/create_new_data_set', factory='tropofy.AppFactory')
     config.add_route('start_app_with_data_set', '/{app_url_name}/start_app_with_data_set/{data_set_id:-?\d+}', factory='tropofy.AppFactory')
     config.add_route('set_data_set_current_step', '/{app_url_name}/set_data_set_current_step/{current_step_index:\d+}/{data_set_id:-?\d+}', factory='tropofy.AppFactory')
-    config.add_route('refresh_widget_from_db', '/{app_url_name}/refresh_widget_from_db/{widget_id:\d+}/{data_set_id:-?\d+}', factory='tropofy.AppFactory')
-    config.add_route('update_widget_to_db', '/{app_url_name}/update_widget_to_db/{widget_id:\d+}/{oper}/{data_set_id:-?\d+}', factory='tropofy.AppFactory')
-    config.add_route('update_widget_from_db', '/{app_url_name}/update_widget_from_db/{widget_id:\d+}/{oper}/{data_set_id:-?\d+}', factory='tropofy.AppFactory')
+    config.add_route('refresh_widget', '/{app_url_name}/refresh_widget/{widget_id:\d+}/{data_set_id:-?\d+}', factory='tropofy.AppFactory')
+    config.add_route('update_widget', '/{app_url_name}/update_widget/{widget_id:\d+}/{oper}/{data_set_id:-?\d+}', factory='tropofy.AppFactory')
     config.add_route('export_data_set', '/{app_url_name}/export_data_set/{data_set_id:-?\d+}', factory='tropofy.AppFactory')
     config.add_route('login', '/{app_url_name}/login')
     config.add_route('logout', '/{app_url_name}/logout')
+    config.add_route('manage_account', '/{app_url_name}/manage_account')
+    config.add_route('manage_mfa', '/{app_url_name}/manage_mfa')
     config.add_route('favicon', '/favicon.ico')
     config.add_route('run_app', '/{app_url_name}', factory='tropofy.AppFactory')  # This needs to be at the end. It's a catch all!
     config.add_route('redirect_to_run_app', '/')  # This needs to be at the end. It's a catch all!
@@ -160,6 +168,7 @@ class RootFactory(object):
 
 
 class AppFactory(object):
-    '''Factory for url's within apps (ajax calls). Needed so people can't innapropriately access ajax urls directly.'''
+    '''Factory to ensure authenticated user (from cookie), and the app is valid.'''
     def __init__(self, request):
-        self.__acl__ = [(Allow, authenticated_userid(request), 'run_app')]
\ No newline at end of file
+        if request.app:
+            self.__acl__ = [(Allow, authenticated_userid(request), 'run_app')]
\ No newline at end of file
