@@ -273,6 +273,7 @@ class AppDataSet(ORMBase):
         session = self.db_session()
         session.add_all(objects)
         session.flush()
+        return len(objects)
 
     def flush(self):
         self.db_session().flush()
@@ -448,6 +449,7 @@ class TaskInterfaceMixin(object):
     SUCCESS = "SUCCESS"
     RUNNING = "RUNNING"
     TERMINATED = "TERMINATED"
+    SUCCESS_WITH_WARNING = "SUCCESS_WITH_WARNING"
 
     def __init__(self, widget_unique_name):
         self.widget_unique_name = widget_unique_name
@@ -522,7 +524,9 @@ class CeleryTask(DataSetMixin, TaskInterfaceMixin):
     SUCCESS = 'SUCCESS'
     FAILURE = 'FAILURE'
     TERMINATED = 'REVOKED'
-    TASK_COMPLETE_STATUS = [SUCCESS, FAILURE, TERMINATED]
+    SUCCESS_WITH_WARNING = "SUCCESS_WITH_WARNING"  # Task ran successfully - however finished with a warning.
+    TASK_COMPLETE_STATUS = [SUCCESS, FAILURE, TERMINATED, SUCCESS_WITH_WARNING]
+    TASK_SUCCESS_STATUS = [SUCCESS, SUCCESS_WITH_WARNING]
 
     task_id = Column(Text, nullable=False)
     terminated_by_user = Column(Boolean, nullable=True)
@@ -593,6 +597,8 @@ class CeleryTask(DataSetMixin, TaskInterfaceMixin):
         finished_status = self._finished_result.finished_status
         if finished_status == CeleryTask.SUCCESS:
             return TaskInterfaceMixin.SUCCESS
+        elif finished_status == CeleryTask.SUCCESS_WITH_WARNING:
+            return TaskInterfaceMixin.SUCCESS_WITH_WARNING
         elif finished_status == CeleryTask.TERMINATED:
             return TaskInterfaceMixin.TERMINATED
         else:  # finished_status == CeleryTask.FAILURE:
@@ -677,7 +683,7 @@ class SynchronousTask(DataSetMixin, TaskInterfaceMixin):
 
 
 class TaskResultMeta(object):
-    """Stores metadata about a celery task. Attached to current_task to store metadata while the task is running. Stored in CeleryTask._finished_task_meta for finished task."""
+    """Stores metadata about a celery task. Attached to current_task to store metadata while the task is running. Stored in CeleryTask._finished_result for finished task."""
 
     def __init__(self):
         self.messages = []
@@ -721,7 +727,7 @@ class TaskResultMeta(object):
         """
         self.end_datetime = datetime.now()
         self.finished_status = finished_status
-        if self.finished_status != CeleryTask.SUCCESS:
+        if self.finished_status not in CeleryTask.TASK_SUCCESS_STATUS:
             self.messages.append(TaskMessage(text="Task execution did not complete successfully - database changes have not been committed.", status=TaskMessage.ERROR))
 
 
