@@ -9,7 +9,7 @@ from tropofy.database.tropofy_orm import DynamicSchemaName
 if DynamicSchemaName.use_app_schemas is None:
     DynamicSchemaName.set_use_app_schemas(True)
 
-from tropofy.app import AppDataSet, CeleryTask, TaskResultMeta # Needs to be after setting .use_app_schemas
+from tropofy.app.data_set import AppDataSet, CeleryTask, TaskResultMeta, TaskMessage  # Needs to be after setting .use_app_schemas
 
 
 # @celeryd_init.connect()
@@ -88,8 +88,8 @@ def task_prerun_handler(sender=None, body=None, **kwargs):
 @task_postrun.connect()
 def task_postrun_handler(sender=None, body=None, **kwargs):
     """Finalises task, ensuring that the connection to the database is closed and commited/rolled back as appropriate on task completion."""
-    finished_status = kwargs['state']
-    task_successful = finished_status == CeleryTask.SUCCESS
+    finished_celery_status = kwargs['state']
+    task_successful = finished_celery_status == CeleryTask.SUCCESS
 
     celery_task = _get_celery_task_from_handler_kwargs(kwargs)
 
@@ -98,11 +98,13 @@ def task_postrun_handler(sender=None, body=None, **kwargs):
 
     task_return_val = kwargs['retval']
     if celery_task:
-        if not celery_task.terminated_by_user:  # Finalises task in :func:`tropofy.app.CeleryTask.terminate` so don't need to do it again.
+        if not celery_task.terminated_by_user:  # Finalises task in :func:`tropofy.app.data_set.CeleryTask.terminate` so don't need to do it again.
             task_meta = current_task._running_task_meta
             if isinstance(task_return_val, Exception):
                 task_meta.add_exception_message(task_return_val)
-            task_meta.finalise_task(finished_status=kwargs['state'])
+
+            finished_status = _get_finished_status(task_meta, finished_celery_status)
+            task_meta.finalise_task(finished_status=finished_status)
             celery_task._finished_result = task_meta
     elif isinstance(task_return_val, Exception):  # Not a CeleryTask - Celery called by something other than ExecuteFunctionWidget
         raise task_return_val
@@ -111,6 +113,13 @@ def task_postrun_handler(sender=None, body=None, **kwargs):
     AppDataSet.db_session.remove()
 
 
+def _get_finished_status(task_meta, finished_celery_status):
+    """If any msg was sent that was a warning, set result as SUCCESS_WITH_WARNING"""
+    if next((msg for msg in task_meta.messages if msg.status==TaskMessage.WARNING), None):
+        return CeleryTask.SUCCESS_WITH_WARNING
+    return finished_celery_status
+
+
 def _get_celery_task_from_handler_kwargs(kwargs):
     """Searches kwargs and args for :class:`tropofy.app.AppDataSet`. Then queries is for task"""
     task_id = kwargs['task_id']
