@@ -383,7 +383,7 @@ class ExcelReader(object):
                     else:
                         progress_messages.extend(["Worksheet %s does not have columns: %s." % (mapping.ws_name, mapping.required_column_names - _ws_headers_as_set(ws))])
                 else:
-                    progress_messages.extend(["There is no sheet named %s." % mapping.ws_name])
+                    progress_messages.extend(["--- Note there is no sheet named '%s', so no instances of %s could be made." % (mapping.ws_name, mapping.class_name)])
             except Exception as e:
                 progress_messages.extend([
                     "Aborted - Data set deleted.",
