@@ -83,46 +83,46 @@ class ExecuteGurobiSolver(ExecuteFunction):
 
 
 class BudgetPieChart(Chart):
-    def get_chart_type(self, data_set):
+    def get_chart_type(self, data_set, **kwargs):
         return Chart.PIECHART
 
-    def get_table_schema(self, data_set):
+    def get_table_schema(self, data_set, **kwargs):
         return {"food": ("string", "food"), "spend": ("number", "Spend")}
 
-    def get_table_data(self, data_set):
+    def get_table_data(self, data_set, **kwargs):
         return [{"food": fs.food_name, "spend": fs.amount * fs.food.cost} for fs in data_set.query(FoodServing).all()]
 
-    def get_column_ordering(self, data_set):
+    def get_column_ordering(self, data_set, **kwargs):
         return ["food", "spend"]
 
-    def get_order_by_column(self, data_set):
+    def get_order_by_column(self, data_set, **kwargs):
         return "food"
 
-    def get_chart_options(self, data_set):
+    def get_chart_options(self, data_set, **kwargs):
         return {'title': 'Diet Cost Breakdown'}
 
 
 class NutritionColumnChart(Chart):
-    def get_chart_type(self, data_set):
+    def get_chart_type(self, data_set, **kwargs):
         return Chart.COLUMNCHART
 
-    def get_table_schema(self, data_set):
+    def get_table_schema(self, data_set, **kwargs):
         return {"nutrition_category": ("string", "Category"), "amount": ("number", "Amount"), "diff_to_maximum": ("number", "Difference to maximum")}
 
-    def get_table_data(self, data_set):
+    def get_table_data(self, data_set, **kwargs):
         nutritionValues = dict(
             (f, dict((c, data_set.query(FoodContents).filter(FoodContents.food_name == f.name).filter(FoodContents.nutrition_category_name == c.name).one().amount)
                                      for c in data_set.query(NutritionCategory).all())) for f in data_set.query(Food).all())
         category = dict((c, sum([nutritionValues[fs.food][c] * fs.amount for fs in data_set.query(FoodServing).all()])) for c in data_set.query(NutritionCategory).all())
         return [{"nutrition_category": c.name, "amount": category[c], "diff_to_maximum": c.max_amount - category[c]} for c in data_set.query(NutritionCategory).all()]
 
-    def get_column_ordering(self, data_set):
+    def get_column_ordering(self, data_set, **kwargs):
         return ["nutrition_category", "amount", "diff_to_maximum"]
 
-    def get_order_by_column(self, data_set):
+    def get_order_by_column(self, data_set, **kwargs):
         return "nutrition_category"
 
-    def get_chart_options(self, data_set):
+    def get_chart_options(self, data_set, **kwargs):
         return {
             'isStacked': 'true',
             'title': 'Nutrition categories with difference to maximum',
