@@ -200,15 +200,15 @@ class MapFlowOutput(KMLMap):
 
 class NetworkInflowChart(Chart):
 
-    def get_chart_type(self, data_set):
+    def get_chart_type(self, data_set, **kwargs):
         return Chart.COLUMNCHART
 
-    def get_table_schema(self, data_set):
+    def get_table_schema(self, data_set, **kwargs):
         commodities = dict([(c.name, ("number", c.name)) for c in data_set.query(Commodity).all()])
         commodities["node"] = ("string", "Node")
         return commodities
 
-    def get_table_data(self, data_set):
+    def get_table_data(self, data_set, **kwargs):
         data = []
         for n in data_set.query(Node).all():
             row = {"node": n.name}
@@ -217,24 +217,24 @@ class NetworkInflowChart(Chart):
             data.append(row)
         return data
 
-    def get_column_ordering(self, data_set):
+    def get_column_ordering(self, data_set, **kwargs):
         return ["node"] + [n.name for n in data_set.query(Commodity).all()]
 
-    def get_chart_options(self, data_set):
+    def get_chart_options(self, data_set, **kwargs):
         return {'title': 'Node Inflows'}
 
 
 class NetworkOutflowChart(Chart):
 
-    def get_chart_type(self, data_set):
+    def get_chart_type(self, data_set, **kwargs):
         return Chart.COLUMNCHART
 
-    def get_table_schema(self, data_set):
+    def get_table_schema(self, data_set, **kwargs):
         commodities = dict([(c.name, ("number", c.name)) for c in data_set.query(Commodity).all()])
         commodities["node"] = ("string", "Node")
         return commodities
 
-    def get_table_data(self, data_set):
+    def get_table_data(self, data_set, **kwargs):
         data = []
         for n in data_set.query(Node).all():
             row = {"node": n.name}
@@ -243,10 +243,10 @@ class NetworkOutflowChart(Chart):
             data.append(row)
         return data
 
-    def get_column_ordering(self, data_set):
+    def get_column_ordering(self, data_set, **kwargs):
         return ["node"] + [n.name for n in data_set.query(Commodity).all()]
 
-    def get_chart_options(self, data_set):
+    def get_chart_options(self, data_set, **kwargs):
         return {'title': 'Node Outflows'}
 
 
