@@ -113,10 +113,10 @@ class ExecuteGurobiSolver(ExecuteFunction):
 
 class RequirementsAndAvailabilityChart(Chart):
 
-    def get_chart_type(self, data_set):
+    def get_chart_type(self, data_set, **kwargs):
         return Chart.COLUMNCHART
 
-    def get_table_schema(self, data_set):
+    def get_table_schema(self, data_set, **kwargs):
         return {
             "day": ("string", "Day"),
             "required": ("number", "Staff Required"),
@@ -124,7 +124,7 @@ class RequirementsAndAvailabilityChart(Chart):
             "shortfall": ("number", "Shortfall")
         }
 
-    def get_table_data(self, data_set):
+    def get_table_data(self, data_set, **kwargs):
         return [{
             'day': r.day,
             'required': r.staff,
@@ -132,10 +132,10 @@ class RequirementsAndAvailabilityChart(Chart):
             'shortfall':max(0, r.staff - len(data_set.query(Availability).filter(Availability.day == r.day).all()))
             } for r in data_set.query(ShiftRequirements).all()]
 
-    def get_column_ordering(self, data_set):
+    def get_column_ordering(self, data_set, **kwargs):
         return ["day", "required", "available", "shortfall"]
 
-    def get_chart_options(self, data_set):
+    def get_chart_options(self, data_set, **kwargs):
         shortfall = sum([max(0, r.staff - len(data_set.query(Availability).filter(Availability.day == r.day).all())) for r in data_set.query(ShiftRequirements).all()])
         if shortfall > 0:
             return {'title': 'Staff Required and Available with Shortfall - Shortfall of %s' % (shortfall)}
@@ -144,22 +144,22 @@ class RequirementsAndAvailabilityChart(Chart):
 
 class AvailabilityByStaffChart(Chart):
 
-    def get_chart_type(self, data_set):
+    def get_chart_type(self, data_set, **kwargs):
         return Chart.COLUMNCHART
 
-    def get_table_schema(self, data_set):
+    def get_table_schema(self, data_set, **kwargs):
         return {"name": ("string", "Name"), "available": ("number", "Availability over Period")}
 
-    def get_table_data(self, data_set):
+    def get_table_data(self, data_set, **kwargs):
         return [{
             'name': s.name,
             'available': len(data_set.query(Availability).filter(Availability.staff_name == s.name).all())
             } for s in data_set.query(Staff).all()]
 
-    def get_column_ordering(self, data_set):
+    def get_column_ordering(self, data_set, **kwargs):
         return ["name", "available"]
 
-    def get_chart_options(self, data_set):
+    def get_chart_options(self, data_set, **kwargs):
         return {'title': 'Staff Availability over Period'}
 
 
@@ -168,22 +168,22 @@ class ShiftsWorkedPieChart(Chart):
     def __init__(self, type_):
         self.type_ = type_
 
-    def get_chart_type(self, data_set):
+    def get_chart_type(self, data_set, **kwargs):
         return Chart.PIECHART
 
-    def get_table_schema(self, data_set):
+    def get_table_schema(self, data_set, **kwargs):
         return {"name": ("string", "Name"), "shifts": ("number", "Shifts Worked")}
 
-    def get_table_data(self, data_set):
+    def get_table_data(self, data_set, **kwargs):
         return [{
             'name': s.name,
             'shifts': len(data_set.query(self.type_).filter(self.type_.staff_name == s.name).all())
             } for s in data_set.query(Staff).all()]
 
-    def get_column_ordering(self, data_set):
+    def get_column_ordering(self, data_set, **kwargs):
         return ["name", "shifts"]
 
-    def get_chart_options(self, data_set):
+    def get_chart_options(self, data_set, **kwargs):
         rates = {s.name: s.rate for s in data_set.query(Staff).all()}
         return {
             'title': 'Shifts Worked, Total Cost = %s' % (sum([rates[s.staff_name] for s in data_set.query(self.type_).all()])),
@@ -196,16 +196,16 @@ class Roster(Chart):
     def __init__(self, type_):
         self.type_ = type_
 
-    def get_chart_type(self, data_set):
+    def get_chart_type(self, data_set, **kwargs):
         return Chart.TIMELINE
 
-    def get_table_schema(self, data_set):
+    def get_table_schema(self, data_set, **kwargs):
         return {"name": ("string", "Name"),
                 "state": ("string", "Shifts Worked"),
                 "start": ("number", "Start"),
                 "end": ("number", "End")}
 
-    def get_table_data(self, data_set):
+    def get_table_data(self, data_set, **kwargs):
         mlpd = 1000
         data = []
         days = [s.day for s in data_set.query(ShiftRequirements).all()]
@@ -216,10 +216,10 @@ class Roster(Chart):
                 data.append({'name': s, 'state': 'on' if shift else 'off', 'start': days.index(day) * mlpd, 'end': (days.index(day) + 1) * mlpd})
         return data
 
-    def get_column_ordering(self, data_set):
+    def get_column_ordering(self, data_set, **kwargs):
         return ["name", "state", "start", "end"]
 
-    def get_chart_options(self, data_set):
+    def get_chart_options(self, data_set, **kwargs):
         return {
             'title': 'Roster',
             'tooltip.isHtml': 'true',
