@@ -65,13 +65,13 @@ class ExecuteLocalSolver(ExecuteFunction):
 
 
 class KnapsackAllocationWeightPieChart(Chart):
-    def get_chart_type(self, data_set):
+    def get_chart_type(self, data_set, **kwargs):
         return Chart.PIECHART
 
-    def get_table_schema(self, data_set):
+    def get_table_schema(self, data_set, **kwargs):
         return {"item": ("string", "Item"), "weight": ("number", "Weight")}
 
-    def get_table_data(self, data_set):
+    def get_table_data(self, data_set, **kwargs):
         items_in_knapsack = data_set.query(KnapsackItem).filter_by(in_knapsack=True).all()
         ks_weight = sum([item.weight for item in items_in_knapsack])
         ks_max_weight = data_set.get_param('max_weight')
@@ -81,13 +81,13 @@ class KnapsackAllocationWeightPieChart(Chart):
             items_in_pie.append({"item": "Unused", "weight": ks_max_weight - ks_weight})
         return items_in_pie
 
-    def get_column_ordering(self, data_set):
+    def get_column_ordering(self, data_set, **kwargs):
         return ["item", "weight"]
 
-    def get_order_by_column(self, data_set):
+    def get_order_by_column(self, data_set, **kwargs):
         return "weight"
 
-    def get_chart_options(self, data_set):
+    def get_chart_options(self, data_set, **kwargs):
         items_in_knapsack = data_set.query(KnapsackItem).filter_by(in_knapsack=True).all()
         ks_value = sum(item.value for item in items_in_knapsack)
         ks_weight = sum(item.weight for item in items_in_knapsack)
