@@ -55,25 +55,25 @@ class ExecuteSLX(ExecuteFunction):
 
 
 class TimeInQueueHistogram(Chart):
-    def get_chart_type(self, data_set):
+    def get_chart_type(self, data_set, **kwargs):
         return Chart.COLUMNCHART
 
-    def get_table_schema(self, data_set):
+    def get_table_schema(self, data_set, **kwargs):
         return {
             "time_in_queue": ("string", "Time in Queue"),
             "percentage": ("number", "%")
         }
 
-    def get_table_data(self, data_set):
+    def get_table_data(self, data_set, **kwargs):
         data = []
         for row in data_set.query(SLXTimeInQueueResults).all():
             data.append({'time_in_queue': row.label, 'percentage': row.percentage/100})
         return data
 
-    def get_column_ordering(self, data_set):
+    def get_column_ordering(self, data_set, **kwargs):
         return ["time_in_queue", "percentage"]
 
-    def get_chart_options(self, data_set):
+    def get_chart_options(self, data_set, **kwargs):
         return {
             'title': 'Time in Queue Summary',
             'legend': {'position': 'none'},
@@ -84,25 +84,25 @@ class TimeInQueueHistogram(Chart):
         }
 
 class TimeInSysHistogram(Chart):
-    def get_chart_type(self, data_set):
+    def get_chart_type(self, data_set, **kwargs):
         return Chart.COLUMNCHART
 
-    def get_table_schema(self, data_set):
+    def get_table_schema(self, data_set, **kwargs):
         return {
             "time_in_system": ("string", "Time in System"),
             "percentage": ("number", "%")
         }
 
-    def get_table_data(self, data_set):
+    def get_table_data(self, data_set, **kwargs):
         data = []
         for row in data_set.query(SLXTimeInSysResults).all():
             data.append({'time_in_system': row.label, 'percentage': row.percentage/100})
         return data
 
-    def get_column_ordering(self, data_set):
+    def get_column_ordering(self, data_set, **kwargs):
         return ["time_in_system", "percentage"]
 
-    def get_chart_options(self, data_set):
+    def get_chart_options(self, data_set, **kwargs):
         return {
             'title': 'Time in System Summary',
             'legend': {'position': 'none'},
