@@ -56,28 +56,28 @@ class StaticKMLFileName(DataSetMixin):
 
 
 class EnrollmentColumnChart(Chart):
-    def get_chart_type(self, data_set):
+    def get_chart_type(self, data_set, **kwargs):
         return Chart.COLUMNCHART
 
-    def get_table_schema(self, data_set):
+    def get_table_schema(self, data_set, **kwargs):
         return {
             "state": ("string", "State"),
             "enrollment": ("number", "Enrollment")
         }
 
-    def get_table_data(self, data_set):
+    def get_table_data(self, data_set, **kwargs):
         data = []
         for row in data_set.query(EnrollmentAndTurnOut).all():
             data.append({'state': row.state_name, 'enrollment': row.enrollment})
         return data
 
-    def get_column_ordering(self, data_set):
+    def get_column_ordering(self, data_set, **kwargs):
         return ["state", "enrollment"]
 
-    def get_order_by_column(self, data_set):
+    def get_order_by_column(self, data_set, **kwargs):
         return "state"
 
-    def get_chart_options(self, data_set):
+    def get_chart_options(self, data_set, **kwargs):
         return {
             'title': 'Number Enrolled',
             'legend': {'position': 'none'},
@@ -85,28 +85,28 @@ class EnrollmentColumnChart(Chart):
 
 
 class TurnOutColumnChart(Chart):
-    def get_chart_type(self, data_set):
+    def get_chart_type(self, data_set, **kwargs):
         return Chart.COLUMNCHART
 
-    def get_table_schema(self, data_set):
+    def get_table_schema(self, data_set, **kwargs):
         return {
             "state": ("string", "State"),
             "turn_out": ("number", "Turn Out")
         }
 
-    def get_table_data(self, data_set):
+    def get_table_data(self, data_set, **kwargs):
         data = []
         for row in data_set.query(EnrollmentAndTurnOut).all():
             data.append({'state': row.state_name, 'turn_out': row.turn_out_percentage})
         return data
 
-    def get_column_ordering(self, data_set):
+    def get_column_ordering(self, data_set, **kwargs):
         return ["state", "turn_out"]
 
-    def get_order_by_column(self, data_set):
+    def get_order_by_column(self, data_set, **kwargs):
         return "state"
 
-    def get_chart_options(self, data_set):
+    def get_chart_options(self, data_set, **kwargs):
         return {
             'title': 'Turn Out %',
             'legend': {'position': 'none'},
@@ -114,28 +114,28 @@ class TurnOutColumnChart(Chart):
 
 
 class TurnOutSwingColumnChart(Chart):
-    def get_chart_type(self, data_set):
+    def get_chart_type(self, data_set, **kwargs):
         return Chart.COLUMNCHART
 
-    def get_table_schema(self, data_set):
+    def get_table_schema(self, data_set, **kwargs):
         return {
             "state": ("string", "State"),
             "turn_out_swing": ("number", "Turn Out")
         }
 
-    def get_table_data(self, data_set):
+    def get_table_data(self, data_set, **kwargs):
         data = []
         for row in data_set.query(EnrollmentAndTurnOut).all():
             data.append({'state': row.state_name, 'turn_out_swing': row.turn_out_swing})
         return data
 
-    def get_column_ordering(self, data_set):
+    def get_column_ordering(self, data_set, **kwargs):
         return ["state", "turn_out_swing"]
 
-    def get_order_by_column(self, data_set):
+    def get_order_by_column(self, data_set, **kwargs):
         return "state"
 
-    def get_chart_options(self, data_set):
+    def get_chart_options(self, data_set, **kwargs):
         return {
             'title': 'Turn Out Swing %',
             'legend': {'position': 'none'},
@@ -143,7 +143,7 @@ class TurnOutSwingColumnChart(Chart):
 
 
 class TotalVotesStackedColumnChart(Chart):
-    def get_chart_type(self, data_set):
+    def get_chart_type(self, data_set, **kwargs):
         return Chart.COLUMNCHART
 
     def get_parties(self):
@@ -152,13 +152,13 @@ class TotalVotesStackedColumnChart(Chart):
     def get_states(self, data_set):
         return list(set([row.state_name for row in data_set.query(ElectedByState).all()]))
 
-    def get_table_schema(self, data_set):
+    def get_table_schema(self, data_set, **kwargs):
         d = {"state": ("string", "State")}
         for party in self.get_parties():
             d[party] = ("number", party)
         return d
 
-    def get_table_data(self, data_set):
+    def get_table_data(self, data_set, **kwargs):
         data = []
         for state in self.get_states(data_set):
             entry = {'state': state}
@@ -170,13 +170,13 @@ class TotalVotesStackedColumnChart(Chart):
             data.append(entry)
         return data
 
-    def get_column_ordering(self, data_set):
+    def get_column_ordering(self, data_set, **kwargs):
         return ["state"] + self.get_parties()
 
-    def get_order_by_column(self, data_set):
+    def get_order_by_column(self, data_set, **kwargs):
         return "state"
 
-    def get_chart_options(self, data_set):
+    def get_chart_options(self, data_set, **kwargs):
         return {
             'isStacked': 'true',
             'title': 'First Preference Totals for Parties with Elected Members',
@@ -193,10 +193,10 @@ class TotalVotesStackedColumnChart(Chart):
 
 
 class ElectedPieChart(Chart):
-    def get_chart_type(self, data_set):
+    def get_chart_type(self, data_set, **kwargs):
         return Chart.PIECHART
 
-    def get_table_schema(self, data_set):
+    def get_table_schema(self, data_set, **kwargs):
         return {
             "party_name": ("string", "Party"),
             "num_elected": ("number", "Members Elected")
@@ -205,20 +205,20 @@ class ElectedPieChart(Chart):
     def get_parties(self):
         return list(set([row.party_name for row in data_set.query(ElectedByState).all()]))
 
-    def get_table_data(self, data_set):
+    def get_table_data(self, data_set, **kwargs):
         elected_per_party = {}
         for row in data_set.query(ElectedByState).all():
             elected_per_party[map_to_major_party(row.party_name)] = elected_per_party[map_to_major_party(row.party_name)] + row.num_elected if elected_per_party.get(map_to_major_party(row.party_name)) else row.num_elected
         data = [{'party_name':k, 'num_elected':v} for k, v in elected_per_party.items()]
         return data
 
-    def get_column_ordering(self, data_set):
+    def get_column_ordering(self, data_set, **kwargs):
         return ["party_name", "num_elected"]
 
-    def get_order_by_column(self, data_set):
+    def get_order_by_column(self, data_set, **kwargs):
         return "party_name"
 
-    def get_chart_options(self, data_set):
+    def get_chart_options(self, data_set, **kwargs):
         return {'title': 'Number Elected',
                 'pieSliceText': 'value',
                 'pieHole': '0.3',
