@@ -39,17 +39,17 @@ class MyKMLMap(KMLMap):
 
 
 class PerformanceBarChart(Chart):
-    def get_chart_type(self, data_set):
+    def get_chart_type(self, data_set, **kwargs):
         return Chart.BARCHART
 
-    def get_table_schema(self, data_set):
+    def get_table_schema(self, data_set, **kwargs):
         return {
             "year": ("string", "Year"),
             "sales": ("number", "Sales"),
             "expenses": ("number", "Expenses")
         }
 
-    def get_table_data(self, data_set):
+    def get_table_data(self, data_set, **kwargs):
         results = []
         years = [y for r in data_set.query(Performance.year).distinct() for y in r]
         for year in years:
@@ -61,13 +61,13 @@ class PerformanceBarChart(Chart):
             })
         return results
 
-    def get_column_ordering(self, data_set):
+    def get_column_ordering(self, data_set, **kwargs):
         return ["year", "sales", "expenses"]
 
-    def get_order_by_column(self, data_set):
+    def get_order_by_column(self, data_set, **kwargs):
         return "year"
 
-    def get_chart_options(self, data_set):
+    def get_chart_options(self, data_set, **kwargs):
         return {
             'title': 'Company Performance',
             'vAxis': {
@@ -78,16 +78,16 @@ class PerformanceBarChart(Chart):
 
 
 class StoreExpensesPieChart(Chart):
-    def get_chart_type(self, data_set):
+    def get_chart_type(self, data_set, **kwargs):
         return Chart.PIECHART
 
-    def get_table_schema(self, data_set):
+    def get_table_schema(self, data_set, **kwargs):
         return {
             "store": ("string", "Store"),
             "expenses": ("number", "Expenses")
         }
 
-    def get_table_data(self, data_set):
+    def get_table_data(self, data_set, **kwargs):
         results = []
         for store in data_set.query(Store).all():
             performances = data_set.query(Performance).filter_by(store_name=store.name).all()
@@ -97,10 +97,10 @@ class StoreExpensesPieChart(Chart):
             })
         return results
 
-    def get_column_ordering(self, data_set):
+    def get_column_ordering(self, data_set, **kwargs):
         return ["store", "expenses"]
 
-    def get_chart_options(self, data_set):
+    def get_chart_options(self, data_set, **kwargs):
         total_expense = sum(p.expenses for p in data_set.query(Performance).all())
         return {
             'title': 'Company Expenses: Total = ${expense}'.format(expense=str(total_expense)),
